Author: AlbrechtS
Date: 2009-02-20 00:24:32 -0800 (Fri, 20 Feb 2009)
New Revision: 6666
Log:
Fixed some typos.


Modified:
   branches/branch-1.3/FL/fl_draw.H

Modified: branches/branch-1.3/FL/fl_draw.H
===================================================================
--- branches/branch-1.3/FL/fl_draw.H    2009-02-20 08:15:32 UTC (rev 6665)
+++ branches/branch-1.3/FL/fl_draw.H    2009-02-20 08:24:32 UTC (rev 6666)
@@ -93,10 +93,10 @@
 
 // rectangles tweaked to exactly fill the pixel rectangle:
 FL_EXPORT void fl_rect(int x, int y, int w, int h);
 /** Draw a 1-pixel border \e inside the given bounding box */
 inline void fl_rect(int x, int y, int w, int h, Fl_Color c) {fl_color(c); 
fl_rect(x,y,w,h);}
 FL_EXPORT void fl_rectf(int x, int y, int w, int h);
-/** Color a rectangle that exactly fills the given bounding box */
+/** Colors a rectangle that exactly fills the given bounding box */
 inline void fl_rectf(int x, int y, int w, int h, Fl_Color c) {fl_color(c); 
fl_rectf(x,y,w,h);}
 
 // line segments:
@@ -162,8 +162,8 @@
     @{ */
 /* NOTE: doxygen comments here to avoid triplication in os-specific sources */
 /**
-  Set the current font, which is then used in various drawing routines,
-  You may call this outside a draw context if necessary to cal fl_width(),
+  Sets the current font, which is then used in various drawing routines.
+  You may call this outside a draw context if necessary to call fl_width(),
   but on X this will open the display.
 
   The font is identified by a \a face and a \a size.
@@ -177,20 +177,20 @@
 
 /**
   Returns the \a face set by the most recent call to fl_font().
-  Tgis can be used to save/restore the font.
+  This can be used to save/restore the font.
 */
 inline Fl_Font fl_font() {return fl_font_;}
 /** current font size */
 extern FL_EXPORT Fl_Fontsize fl_size_;
 /**
-  Returns the \a face set by the most recent call to fl_font().
-  Tgis can be used to save/restore the font.
+  Returns the \a size set by the most recent call to fl_font().
+  This can be used to save/restore the font.
 */
 inline Fl_Fontsize fl_size() {return fl_size_;}
 
 // information you can get about the current font:
 /**
-  Recommended minimum line spacing for the current font.
+  Returns the recommended minimum line spacing for the current font.
   You can also use the value of \a size passed to fl_font()
 */
 FL_EXPORT int   fl_height();   // using "size" should work ok
@@ -203,7 +203,7 @@
 */
 inline int fl_height(int, int size) {return size;}
 /**
-  Recommended distance above the bottom of a fl_height() tall box to
+  Returns the recommended distance above the bottom of a fl_height() tall box 
to
   draw the text at so it looks centered vertically in that box.
 */
 FL_EXPORT int   fl_descent();
@@ -239,21 +239,22 @@
 /** \addtogroup  fl_drawings
     @{ */
 /**
-  Draw a nul-terminated string starting at the given location.
+  Draws a nul-terminated string starting at the given location.
+
   Text is aligned to the left and to the baseline of the font.
-  To alighn to the bottom, subtract fl_descent() from \a y.
-  To alignn to the top, subtract fl_descent() and add fl_height().
-  This version fo fl_draw provides direct access to the text drawing
+  To align to the bottom, subtract fl_descent() from \a y.
+  To align to the top, subtract fl_descent() and add fl_height().
+  This version of fl_draw provides direct access to the text drawing
   function of the underlying OS. It does not apply any special handling
   to control characters.
 */
 FL_EXPORT void fl_draw(const char* str, int x, int y);
 /**
-  Draw an array of \a n characters starting at the given location.
+  Draws an array of \a n characters starting at the given location.
 */
 FL_EXPORT void fl_draw(const char* str, int n, int x, int y);
 /**
-  Draw and array of \a n characters right to left starting at given location.
+  Draws an array of \a n characters right to left starting at given location.
 */
 FL_EXPORT void fl_rtl_draw(const char*, int n, int x, int y);
 FL_EXPORT void fl_measure(const char* str, int& x, int& y,
@@ -93,10 +93,10 @@
 // rectangles tweaked to exactly fill the pixel rectangle:
 FL_EXPORT void fl_rect(int x, int y, int w, int h);
-/** Draw a 1-pixel border \e inside the given bounding box */
+/** Draws a 1-pixel border \e inside the given bounding box */
 inline void fl_rect(int x, int y, int w, int h, Fl_Color c) {fl_color(c); 
fl_rect(x,y,w,h);}

_______________________________________________
fltk-commit mailing list
[email protected]
http://lists.easysw.com/mailman/listinfo/fltk-commit

Reply via email to